@@ -1,3 +1,3 @@
-from .optimization import appx_policy_itr, learning_exploring_rules, opt_support, stoch_approx
+from .optimization import learning_exploring_rules, opt_support, stoch_approx
 from .plots import econ_eval_plots, histogram, plot_support, pop_pyramids, prob_dists, sample_paths
 from .support import econ_eval_support, misc_functions, misc_classes, simulation
